@@ -393,8 +393,11 @@ class PlaywrightState(LibraryComponent):
         recordVideo: Optional[RecordVideo] = None,
         recordHar: Optional[RecordHar] = None,
         tracing: Optional[str] = None,
+        screen: Optional[Dict[str, int]] = None,
+        storageState: Optional[str] = None,
     ) -> str:
         """Create a new BrowserContext with specified options.
+
         See `Browser, Context and Page` for more information about BrowserContext.
 
         Returns a stable identifier for the created context
@@ -426,8 +429,8 @@ class PlaywrightState(LibraryComponent):
         ``javaScriptEnabled`` Whether or not to enable JavaScript in the context.
         Defaults to True.
 
-        ``timezoneId`` Changes the timezone of the context.
-        See [https://source.chromium.org/chromium/chromium/src/+/master:third_party/icu/source/data/misc/metaZones.txt | ICU’s metaZones.txt]
+        ``timezoneId`` Changes the timezone of the context. See
+        [https://source.chromium.org/chromium/chromium/src/+/master:third_party/icu/source/data/misc/metaZones.txt | ICU’s metaZones.txt]
         for a list of supported timezone IDs.
 
         ``geolocation`` Sets the geolocation. No location is set by default.
@@ -440,8 +443,8 @@ class PlaywrightState(LibraryComponent):
         Locale will affect ``navigator.language`` value, ``Accept-Language`` request header value
         as well as number and date formatting rules.
 
-        ``permissions`` A list of permissions to grant to all pages in this context.
-        See [https://playwright.dev/docs/api/class-browsercontext#browsercontextgrantpermissionspermissions-options| grantPermissions]
+        ``permissions`` A list of permissions to grant to all pages in this context. See
+        [https://playwright.dev/docs/api/class-browsercontext#browsercontextgrantpermissionspermissions-options| grantPermissions]
         for more details.
 
         ``extraHTTPHeaders`` A dictionary containing additional HTTP headers
@@ -463,8 +466,8 @@ class PlaywrightState(LibraryComponent):
         is enabled, all secrets are written as plain text in Playwright debugs logs.
 
         ``colorScheme`` Emulates 'prefers-colors-scheme'
-        media feature, supported values are 'light', 'dark', 'no-preference'.
-        See [https://playwright.dev/docs/api/class-page#pageemulatemediaparams|emulateMedia(options)]
+        media feature, supported values are 'light', 'dark', 'no-preference'. See
+        [https://playwright.dev/docs/api/class-page#pageemulatemediaparams|emulateMedia(options)]
         for more details. Defaults to ``light``.
 
         ``proxy`` Network proxy settings to use with this context.
@@ -511,12 +514,20 @@ class PlaywrightState(LibraryComponent):
         The ${OUTPUTDIR}/browser/ is removed at the first suite startup.
 
         ``tracing`` is file name where the [https://playwright.dev/docs/api/class-tracing/|tracing]
-         file is saved. Example trace.zip will be saved to ${OUTPUT_DIR}/traces.zip. Temporary trace
-         files will be saved to ${OUTPUT_DIR}/Browser/traces. If file name is defined, tracing will
-         be enabled for all pages in the context. Tracing is automatically closed when context is
-         closed. Temporary trace files will be automatically deleted at start of each test
-         execution. Trace file can be opened after the test execution by running command from
-         shell: `rfbrowser show-trace -F /path/to/trace.zip`.
+        file is saved. Example trace.zip will be saved to ${OUTPUT_DIR}/traces.zip. Temporary trace
+        files will be saved to ${OUTPUT_DIR}/Browser/traces. If file name is defined, tracing will
+        be enabled for all pages in the context. Tracing is automatically closed when context is
+        closed. Temporary trace files will be automatically deleted at start of each test
+        execution. Trace file can be opened after the test execution by running command from
+        shell: `rfbrowser show-trace -F /path/to/trace.zip`.
+
+        ``screen``
+        Emulates consistent window screen size available inside web page via window.screen.
+        Is only used when the viewport is set.
+        - Example {'width': 414, 'height': 896}
+
+        ``storageState`` restores the storage stated created by the `Save Storage State`
+        keyword. Must mbe full path to the file.
 
         Example:
         | Test an iPhone
@@ -534,6 +545,10 @@ class PlaywrightState(LibraryComponent):
         params = locals_to_params(locals())
         params = self._set_video_path(params)
         params = self._set_video_size_to_int(params)
+        if storageState and not Path(storageState).is_file():
+            raise ValueError(
+                f"storageState argument value '{storageState}' is not file, but it should be."
+            )
         if "httpCredentials" in params and params["httpCredentials"] is not None:
             secret = self.resolve_secret(
                 httpCredentials, params.get("httpCredentials"), "httpCredentials"
@@ -548,7 +563,6 @@ class PlaywrightState(LibraryComponent):
         logger.info(json.dumps(masked_params, default=str))
         trace_file = Path(self.outputdir, trace_file) if tracing else ""
         response = self._new_context(options, hideRfBrowser, trace_file)
-        print(response.contextOptions)
         context_options = self._mask_credentials(json.loads(response.contextOptions))
         logger.info(response.log)
         logger.info(context_options)
@@ -970,3 +984,51 @@ class PlaywrightState(LibraryComponent):
             ):
                 return [context]
         return []
+
+    @keyword(tags=("Getter", "BrowserControl"))
+    def save_storage_state(self) -> str:
+        """Saves the current active context storage state to a file.
+
+        Web apps use cookie-based or token-based authentication, where
+        authenticated state is stored as
+        [https://developer.mozilla.org/en-US/docs/Web/HTTP/Cookies|cookies]
+        or in
+        [https://developer.mozilla.org/en-US/docs/Web/API/Storage|local storage].
+        Keyword retrieves the storage state from authenticated contexts and
+        save it to disk. Then `New Context` can be created with prepopulated
+        state.
+
+        Please note state file contains secrets and should not be shared
+        with people outside of your organisation.
+
+        The file is created in ${OUTPUTDIR}/browser/state folder and file(s)
+        are automatically deleted when new test execution starts. File path
+        is returned by the keyword.
+
+        Example:
+        | Test Case
+        |     `New context`
+        |     `New Page`    https://login.page.html
+        |     #  Perform login
+        |     `Fill Secret`    id=username    $username
+        |     `Fill Secret`    id=password    $password
+        |     `Click`    id=button
+        |     `Get Text`    id=header    ==    Something
+        |     #  Save storage to disk
+        |     ${state_file} =    `Save Storage State`
+        |     #  Create new context with saved state
+        |     `New context`    storageState=${state_file}
+        |     `New Page`    https://login.page.html
+        |     #  Login is not needed because authentication is read from state file
+        |     `Get Text`    id=header    ==    Something
+        """
+        file = str(self.state_file / f"{str(uuid4())}.json")
+        self.state_file.mkdir(parents=True, exist_ok=True)
+        log = self._save_storage_state(file)
+        logger.info(log)
+        return file
+
+    def _save_storage_state(self, path: str) -> str:
+        with self.playwright.grpc_channel() as stub:
+            response = stub.SaveStorageState(Request().FilePath(path=path))
+        return response.log
